@@ -20,7 +20,6 @@
 #include "dialog.h"
 
 class VimeoSearchTypeModel;
-class VimeoSearchOrderModel;
 class ValueSelector;
 class QLineEdit;
 class QDialogButtonBox;
@@ -39,16 +38,13 @@ private Q_SLOTS:
     
     void showHistoryDialog();
 
-    void onSearchOrderChanged(const QVariant &order);
     void onSearchTextChanged(const QString &text);
-    void onSearchTypeChanged(const QVariant &type);
+    void onSearchTypeChanged();
     
 private:
     VimeoSearchTypeModel *m_typeModel;
-    VimeoSearchOrderModel *m_orderModel;
     
     ValueSelector *m_typeSelector;
-    ValueSelector *m_orderSelector;
     QLineEdit *m_searchEdit;
     QDialogButtonBox *m_buttonBox;
     QPushButton *m_historyButton;
