@@ -20,7 +20,7 @@
 #include "stackedwindow.h"
 #include "vimeovideomodel.h"
 
-class VimeoVideoDelegate;
+class VideoDelegate;
 class ImageCache;
 class ListView;
 class QLabel;
@@ -62,7 +62,7 @@ private:
     ImageCache *m_cache;
     
     ListView *m_view;
-    VimeoVideoDelegate *m_delegate;
+    VideoDelegate *m_delegate;
     QActionGroup *m_viewGroup;
     QAction *m_listAction;
     QAction *m_gridAction;
