@@ -18,7 +18,6 @@
 #define PLUGINNAVMODEL_H
 
 #include "selectionmodel.h"
-#include "resources.h"
 #include "resourcesplugins.h"
 
 class PluginNavModel : public SelectionModel
@@ -34,9 +33,8 @@ public:
         setTextAlignment(Qt::AlignLeft | Qt::AlignVCenter);
     }
     
-    inline QString service() { 
+    inline QString service() const { 
         return m_service;
-    
     }
     
     inline void setService(const QString &s) {
@@ -51,25 +49,13 @@ public Q_SLOTS:
     inline void reload() {
         clear();
         ResourcesPlugin plugin = ResourcesPlugins::instance()->getPluginFromName(service());
-#ifdef NAV_SEARCH
-        if (!plugin.supportedSearchResources.isEmpty()) {
+        
+        if (!plugin.searchResources.isEmpty()) {
             append(tr("Search"), "");
         }
-#endif
-        //if (plugin.supportedListResources.contains(Resources::CATEGORY)) {
-        //    append(tr("Categories"), Resources::CATEGORY);
-        //}
         
-        if (plugin.supportedListResources.contains(Resources::PLAYLIST)) {
-            append(tr("Playlists"), Resources::PLAYLIST);
-        }
-        
-        if (plugin.supportedListResources.contains(Resources::USER)) {
-            append(tr("Users"), Resources::USER);
-        }
-        
-        if (plugin.supportedListResources.contains(Resources::VIDEO)) {
-            append(tr("Videos"), Resources::VIDEO);
+        foreach (ListResource resource, plugin.listResources.values()) {
+            append(resource.value("name").toString(), resource);
         }
     }
     
